@@ -56,6 +56,7 @@ from .device import Device
 from .device_recipe import DeviceRecipe
 from .device_recipes import DeviceRecipes
 from .devices import Devices
+from .edge_deployment import EdgeDeployment
 from .edge_deployments import EdgeDeployments
 from .event import Event
 from .events import Events
@@ -81,9 +82,13 @@ from .flow_version import FlowVersion
 from .flow_versions import FlowVersions
 from .flows import Flows
 from .instance import Instance
+from .instance_api_token import InstanceApiToken
+from .instance_api_tokens import InstanceApiTokens
 from .instance_member import InstanceMember
 from .instance_members import InstanceMembers
 from .instance_org import InstanceOrg
+from .instance_org_invite import InstanceOrgInvite
+from .instance_org_invites import InstanceOrgInvites
 from .instance_org_member import InstanceOrgMember
 from .instance_org_members import InstanceOrgMembers
 from .instance_orgs import InstanceOrgs
@@ -96,6 +101,8 @@ from .notebooks import Notebooks
 from .org import Org
 from .org_invites import OrgInvites
 from .orgs import Orgs
+from .user_api_token import UserApiToken
+from .user_api_tokens import UserApiTokens
 from .webhook import Webhook
 from .webhooks import Webhooks
 from .losant_error import LosantError
@@ -109,7 +116,7 @@ class Client(object):
 
     User API for accessing Losant data
 
-    Built For Version 1.20.0
+    Built For Version 1.21.1
     """
 
     def __init__(self, auth_token=None, url="https://api.losant.com"):
@@ -143,6 +150,7 @@ class Client(object):
         self.device_recipe = DeviceRecipe(self)
         self.device_recipes = DeviceRecipes(self)
         self.devices = Devices(self)
+        self.edge_deployment = EdgeDeployment(self)
         self.edge_deployments = EdgeDeployments(self)
         self.event = Event(self)
         self.events = Events(self)
@@ -168,9 +176,13 @@ class Client(object):
         self.flow_versions = FlowVersions(self)
         self.flows = Flows(self)
         self.instance = Instance(self)
+        self.instance_api_token = InstanceApiToken(self)
+        self.instance_api_tokens = InstanceApiTokens(self)
         self.instance_member = InstanceMember(self)
         self.instance_members = InstanceMembers(self)
         self.instance_org = InstanceOrg(self)
+        self.instance_org_invite = InstanceOrgInvite(self)
+        self.instance_org_invites = InstanceOrgInvites(self)
         self.instance_org_member = InstanceOrgMember(self)
         self.instance_org_members = InstanceOrgMembers(self)
         self.instance_orgs = InstanceOrgs(self)
@@ -183,6 +195,8 @@ class Client(object):
         self.org = Org(self)
         self.org_invites = OrgInvites(self)
         self.orgs = Orgs(self)
+        self.user_api_token = UserApiToken(self)
+        self.user_api_tokens = UserApiTokens(self)
         self.webhook = Webhook(self)
         self.webhooks = Webhooks(self)
 
@@ -194,7 +208,7 @@ class Client(object):
             params = {}
 
         headers["Accept"] = "application/json"
-        headers["Accept-Version"] = "^1.20.0"
+        headers["Accept-Version"] = "^1.21.1"
         if self.auth_token:
             headers["Authorization"] = "Bearer {0}".format(self.auth_token)
 
