@@ -357,7 +357,7 @@ class Flow(object):
         The client must be configured with a valid api
         access token to call this action. The token
         must include at least one of the following scopes:
-        all.Application, all.Organization, all.User, flow.*, or flow.getStorageEntriesMetadata.
+        all.Application, all.Application.read, all.Organization, all.Organization.read, all.User, all.User.read, flow.*, or flow.getStorageEntriesMetadata.
 
         Parameters:
         *  {string} applicationId - ID associated with the application
